@@ -8,10 +8,15 @@
 #include "ASN1Util.h"
 #include "SecurityProtocol.h"
 
+#include <QLoggingCategory>
+
 
 using namespace governikus;
 
 
+Q_DECLARE_LOGGING_CATEGORY(card)
+
+
 namespace governikus
 {
 
