@@ -2,18 +2,15 @@
  * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
-/*!
- * \brief Command to transmit data to/from the card.
- */
-
 #pragma once
 
 #include "BaseCardCommand.h"
 #include "CardConnectionWorker.h"
 #include "InputAPDUInfo.h"
 
+
 class test_TransmitCommand;
-class test_CardConnection;
+
 
 namespace governikus
 {
@@ -23,7 +20,6 @@ class TransmitCommand
 {
 	Q_OBJECT
 	friend class ::test_TransmitCommand;
-	friend class ::test_CardConnection;
 
 	private:
 		const QList<InputAPDUInfo> mInputApduInfos;
