@@ -9,53 +9,53 @@
 #include <QtPlugin>
 
 
-Q_IMPORT_PLUGIN(SimulatorReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(SimulatorReaderManagerPlugin)
 
 #if !defined(Q_OS_WINRT) && !defined(INTEGRATED_SDK)
-Q_IMPORT_PLUGIN(RemoteIfdReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(RemoteIfdReaderManagerPlugin)
 #endif
 
 #if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS) && !defined(Q_OS_WINRT)
-Q_IMPORT_PLUGIN(PcscReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(PcscReaderManagerPlugin)
 
 	#if !defined(INTEGRATED_SDK) || defined(CONTAINER_SDK)
-Q_IMPORT_PLUGIN(UIPlugInWebService)
-Q_IMPORT_PLUGIN(UIPlugInProxy)
+Q_IMPORT_PLUGIN(UiPluginWebService)
+Q_IMPORT_PLUGIN(UiPluginProxy)
 	#endif
 
 	#if defined(USE_SMARTEID) && (defined(CONTAINER_SDK) || !defined(QT_NO_DEBUG))
-Q_IMPORT_PLUGIN(SmartReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(SmartReaderManagerPlugin)
 	#endif
 
 #endif
 
 
 #if defined(Q_OS_ANDROID)
-Q_IMPORT_PLUGIN(NfcReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(NfcReaderManagerPlugin)
 
 	#ifndef INTEGRATED_SDK
-Q_IMPORT_PLUGIN(UIPlugInScheme)
+Q_IMPORT_PLUGIN(UiPluginScheme)
 
 		#ifdef USE_SMARTEID
-Q_IMPORT_PLUGIN(UIPlugInLocalIfd)
-Q_IMPORT_PLUGIN(SmartReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(UiPluginLocalIfd)
+Q_IMPORT_PLUGIN(SmartReaderManagerPlugin)
 		#endif
 
 	#else
-Q_IMPORT_PLUGIN(LocalIfdReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(LocalIfdReaderManagerPlugin)
 	#endif
 
 #endif
 
 
 #if defined(Q_OS_IOS)
-Q_IMPORT_PLUGIN(NfcReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(NfcReaderManagerPlugin)
 
 	#ifndef INTEGRATED_SDK
-Q_IMPORT_PLUGIN(UIPlugInScheme)
+Q_IMPORT_PLUGIN(UiPluginScheme)
 
 		#ifdef USE_SMARTEID
-Q_IMPORT_PLUGIN(SmartReaderManagerPlugIn)
+Q_IMPORT_PLUGIN(SmartReaderManagerPlugin)
 		#endif
 
 Q_IMPORT_PLUGIN(QJpegPlugin)
@@ -66,24 +66,24 @@ Q_IMPORT_PLUGIN(QSvgPlugin)
 
 
 #if defined(Q_OS_ANDROID) || !defined(QT_NO_DEBUG)
-Q_IMPORT_PLUGIN(UIPlugInAidl)
+Q_IMPORT_PLUGIN(UiPluginAidl)
 #endif
 
 #ifndef INTEGRATED_SDK
-Q_IMPORT_PLUGIN(UIPlugInQml)
+Q_IMPORT_PLUGIN(UiPluginQml)
 #endif
 
 #if defined(INTEGRATED_SDK) && !defined(Q_OS_ANDROID) && !defined(CONTAINER_SDK)
-Q_IMPORT_PLUGIN(UIPlugInFunctional)
+Q_IMPORT_PLUGIN(UiPluginFunctional)
 #endif
 
 #if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS) && (!defined(INTEGRATED_SDK) || defined(CONTAINER_SDK))
-Q_IMPORT_PLUGIN(UIPlugInAutomatic)
-Q_IMPORT_PLUGIN(UIPlugInWebSocket)
+Q_IMPORT_PLUGIN(UiPluginAutomatic)
+Q_IMPORT_PLUGIN(UiPluginWebSocket)
 #endif
 
 #if !defined(Q_OS_IOS) || defined(INTEGRATED_SDK)
-Q_IMPORT_PLUGIN(UIPlugInJson)
+Q_IMPORT_PLUGIN(UiPluginJson)
 #endif
 
 Q_DECL_EXPORT int main(int argc, char** argv)
