@@ -7,11 +7,13 @@
 
 using namespace governikus;
 
+
 AppSettings::AppSettings()
 	: QObject()
 	, mGeneralSettings()
 	, mPreVerificationSettings()
 	, mRemoteReaderSettings()
+	, mSimulatorSettings()
 {
 }
 
@@ -32,3 +34,9 @@ RemoteServiceSettings& AppSettings::getRemoteServiceSettings()
 {
 	return mRemoteReaderSettings;
 }
+
+
+SimulatorSettings& AppSettings::getSimulatorSettings()
+{
+	return mSimulatorSettings;
+}
