@@ -4,6 +4,8 @@
 
 #include "ApplicationModel.h"
 
+#include <QLoggingCategory>
+
 using namespace governikus;
 
 Q_DECLARE_LOGGING_CATEGORY(qml)
@@ -12,3 +14,10 @@ void ApplicationModel::showSettings(const ApplicationModel::Settings& pAction) c
 {
 	qCWarning(qml) << "NOT IMPLEMENTED:" << pAction;
 }
+
+
+bool ApplicationModel::isScreenReaderRunning() const
+{
+	qCWarning(qml) << "NOT IMPLEMENTED";
+	return false;
+}
