@@ -5,6 +5,7 @@
 #pragma once
 
 #include <QSortFilterProxyModel>
+#include <QtQml/qqmlregistration.h>
 
 namespace governikus
 {
@@ -13,6 +14,8 @@ class SortedReaderModel
 	: public QSortFilterProxyModel
 {
 	Q_OBJECT
+	QML_UNCREATABLE("Used by ReaderModel only")
+	QML_ELEMENT
 
 	protected:
 		[[nodiscard]] bool lessThan(const QModelIndex& source_left, const QModelIndex& source_right) const override;
