@@ -23,11 +23,11 @@
 using namespace governikus;
 
 INIT_FUNCTION([] {
-			qRegisterMetaType<QList<int>>("QList<ReaderManagerPlugInType>");
+			qRegisterMetaType<QList<int>>("QList<ReaderManagerPluginType>");
 		})
 
-WorkflowModel::WorkflowModel(QObject* pParent)
-	: QObject(pParent)
+WorkflowModel::WorkflowModel()
+	: QObject()
 	, mContext()
 #if defined(Q_OS_IOS)
 	, mRemoteScanWasRunning(false)
@@ -37,11 +37,11 @@ WorkflowModel::WorkflowModel(QObject* pParent)
 	connect(Env::getSingleton<ReaderManager>(), &ReaderManager::fireCardRemoved, this, &WorkflowModel::fireHasCardChanged);
 	connect(Env::getSingleton<ReaderManager>(), &ReaderManager::fireReaderAdded, this, &WorkflowModel::fireHasCardChanged);
 	connect(Env::getSingleton<ReaderManager>(), &ReaderManager::fireReaderRemoved, this, &WorkflowModel::fireHasCardChanged);
-	connect(Env::getSingleton<SmartModel>(), &SmartModel::fireSmartStateChanged, this, &WorkflowModel::fireIsCurrentSmartCardAllowedChanged);
+	connect(Env::getSingleton<SmartModel>(), &SmartModel::fireStateChanged, this, &WorkflowModel::fireIsCurrentSmartCardAllowedChanged);
 
 	connect(Env::getSingleton<ApplicationModel>(), &ApplicationModel::fireApplicationStateChanged, this, &WorkflowModel::onApplicationStateChanged);
 
-	connect(&Env::getSingleton<AppSettings>()->getGeneralSettings(), &GeneralSettings::fireDeveloperOptionsChanged, this, &WorkflowModel::fireSupportedPlugInTypesChanged);
+	connect(&Env::getSingleton<AppSettings>()->getGeneralSettings(), &GeneralSettings::fireDeveloperOptionsChanged, this, &WorkflowModel::fireSupportedPluginTypesChanged);
 }
 
 
@@ -53,14 +53,16 @@ void WorkflowModel::resetWorkflowContext(const QSharedPointer<WorkflowContext>&
 		connect(mContext.data(), &WorkflowContext::fireStateChanged, this, &WorkflowModel::fireCurrentStateChanged);
 		connect(mContext.data(), &WorkflowContext::fireStateChanged, this, &WorkflowModel::fireStateEntered);
 		connect(mContext.data(), &WorkflowContext::fireResultChanged, this, &WorkflowModel::fireResultChanged);
-		connect(mContext.data(), &WorkflowContext::fireReaderPlugInTypesChanged, this, &WorkflowModel::fireReaderPlugInTypeChanged);
-		connect(mContext.data(), &WorkflowContext::fireReaderPlugInTypesChanged, this, &WorkflowModel::fireHasCardChanged);
+		connect(mContext.data(), &WorkflowContext::fireReaderPluginTypesChanged, this, &WorkflowModel::fireReaderPluginTypeChanged);
+		connect(mContext.data(), &WorkflowContext::fireReaderPluginTypesChanged, this, &WorkflowModel::fireHasCardChanged);
 		connect(mContext.data(), &WorkflowContext::fireCardConnectionChanged, this, &WorkflowModel::fireSelectedReaderChanged);
 		connect(mContext.data(), &WorkflowContext::fireCardConnectionChanged, this, &WorkflowModel::fireHasCardChanged);
 		connect(mContext.data(), &WorkflowContext::fireEidTypeMismatchChanged, this, &WorkflowModel::fireIsCurrentSmartCardAllowedChanged);
 		connect(mContext.data(), &WorkflowContext::fireEidTypeMismatchChanged, this, &WorkflowModel::fireEidTypeMismatchErrorChanged);
 		connect(mContext.data(), &WorkflowContext::fireNextWorkflowPending, this, &WorkflowModel::fireNextWorkflowPendingChanged);
 		connect(mContext.data(), &WorkflowContext::fireRemoveCardFeedbackChanged, this, &WorkflowModel::fireRemoveCardFeedbackChanged);
+		connect(mContext.data(), &WorkflowContext::firePaceResultUpdated, this, &WorkflowModel::onPaceResultUpdated);
+		connect(mContext.data(), &WorkflowContext::firePaceResultUpdated, this, &WorkflowModel::fireLastReturnCodeChanged);
 		Q_EMIT fireWorkflowStarted();
 	}
 	else
@@ -97,31 +99,41 @@ bool WorkflowModel::isMaskedError() const
 }
 
 
-ReaderManagerPlugInType WorkflowModel::getReaderPlugInType() const
+CardReturnCode WorkflowModel::getLastReturnCode() const
 {
-	if (mContext && !mContext->getReaderPlugInTypes().isEmpty())
+	if (mContext)
 	{
-		return mContext->getReaderPlugInTypes().at(0);
+		return mContext->getLastPaceResult();
 	}
-
-	return ReaderManagerPlugInType::UNKNOWN;
+	return CardReturnCode::UNDEFINED;
 }
 
 
-void WorkflowModel::setReaderPlugInType(ReaderManagerPlugInType pReaderPlugInType)
+ReaderManagerPluginType WorkflowModel::getReaderPluginType() const
+{
+	if (mContext && !mContext->getReaderPluginTypes().isEmpty())
+	{
+		return mContext->getReaderPluginTypes().at(0);
+	}
+
+	return ReaderManagerPluginType::UNKNOWN;
+}
+
+
+void WorkflowModel::setReaderPluginType(ReaderManagerPluginType pReaderPluginType)
 {
 	if (!mContext)
 	{
 		return;
 	}
-	mContext->setReaderPlugInTypes({pReaderPlugInType});
+	mContext->setReaderPluginTypes({pReaderPluginType});
 
 	auto& settings = Env::getSingleton<AppSettings>()->getGeneralSettings();
-	settings.setLastReaderPluginType(getEnumName(pReaderPlugInType));
+	settings.setLastReaderPluginType(getEnumName(pReaderPluginType));
 }
 
 
-void WorkflowModel::insertCard(ReaderManagerPlugInType pType) const
+void WorkflowModel::insertCard(ReaderManagerPluginType pType) const
 {
 	auto* const readerManager = Env::getSingleton<ReaderManager>();
 	const auto& readerInfos = readerManager->getReaderInfos(ReaderFilter({pType}));
@@ -133,15 +145,15 @@ void WorkflowModel::insertCard(ReaderManagerPlugInType pType) const
 }
 
 
-void WorkflowModel::insertSmartCard()
+void WorkflowModel::insertSmartCard() const
 {
-	insertCard(ReaderManagerPlugInType::SMART);
+	insertCard(ReaderManagerPluginType::SMART);
 }
 
 
-void WorkflowModel::insertSimulator()
+void WorkflowModel::insertSimulator() const
 {
-	insertCard(ReaderManagerPlugInType::SIMULATOR);
+	insertCard(ReaderManagerPluginType::SIMULATOR);
 }
 
 
@@ -167,7 +179,7 @@ void WorkflowModel::startScanExplicitly()
 {
 	if (mContext)
 	{
-		Q_EMIT mContext->fireReaderPlugInTypesChanged(true);
+		Q_EMIT mContext->fireReaderPluginTypesChanged(true);
 	}
 }
 
@@ -187,7 +199,7 @@ bool WorkflowModel::isRemoteReader() const
 {
 	if (mContext && mContext->getCardConnection())
 	{
-		return mContext->getCardConnection()->getReaderInfo().getPlugInType() == ReaderManagerPlugInType::REMOTE_IFD;
+		return mContext->getCardConnection()->getReaderInfo().getPluginType() == ReaderManagerPluginType::REMOTE_IFD;
 	}
 
 	return false;
@@ -201,7 +213,7 @@ bool WorkflowModel::hasCard() const
 		return false;
 	}
 
-	const auto& readerInfos = Env::getSingleton<ReaderManager>()->getReaderInfos(ReaderFilter({getReaderPlugInType()}));
+	const auto& readerInfos = Env::getSingleton<ReaderManager>()->getReaderInfos(ReaderFilter({getReaderPluginType()}));
 	const auto& readersWithEid = filter<ReaderInfo>([](const ReaderInfo& i){return i.hasEid();}, readerInfos);
 	return !readersWithEid.isEmpty();
 }
@@ -214,23 +226,17 @@ bool WorkflowModel::isCurrentSmartCardAllowed() const
 }
 
 
-bool WorkflowModel::isSmartSupported() const
+QList<ReaderManagerPluginType> WorkflowModel::getSupportedReaderPluginTypes() const
 {
-	return getSupportedReaderPlugInTypes().contains(ReaderManagerPlugInType::SMART);
-}
+	auto supported = Enum<ReaderManagerPluginType>::getList();
 
-
-QList<ReaderManagerPlugInType> WorkflowModel::getSupportedReaderPlugInTypes() const
-{
-	auto supported = Enum<ReaderManagerPlugInType>::getList();
-
-	if (!Env::getSingleton<AppSettings>()->getGeneralSettings().isSimulatorEnabled())
+	if (!Env::getSingleton<AppSettings>()->getSimulatorSettings().isEnabled())
 	{
-		supported.removeOne(ReaderManagerPlugInType::SIMULATOR);
+		supported.removeOne(ReaderManagerPluginType::SIMULATOR);
 	}
 
 #if !__has_include("SmartManager.h")
-	supported.removeOne(ReaderManagerPlugInType::SMART);
+	supported.removeOne(ReaderManagerPluginType::SMART);
 #endif
 
 	return supported;
@@ -322,6 +328,21 @@ QString WorkflowModel::getStatusHintText() const
 }
 
 
+QString WorkflowModel::getStatusHintTitle() const
+{
+	switch (getStatusCode())
+	{
+		case GlobalStatus::Code::Card_Puk_Blocked:
+		case GlobalStatus::Code::Card_Pin_Deactivated:
+			//: LABEL ALL_PLATFORMS Hint title to assist the user on how to set a new PIN
+			return tr("Set a new PIN");
+
+		default:
+			return QString();
+	}
+}
+
+
 QString WorkflowModel::getStatusHintActionText() const
 {
 	switch (getStatusCode())
@@ -382,20 +403,20 @@ void WorkflowModel::setInitialPluginType()
 	const GeneralSettings& settings = Env::getSingleton<AppSettings>()->getGeneralSettings();
 
 	const QString& lastReaderPluginTypeString = settings.getLastReaderPluginType();
-	const auto& lastReaderPluginType = Enum<ReaderManagerPlugInType>::fromString(lastReaderPluginTypeString, ReaderManagerPlugInType::UNKNOWN);
+	const auto& lastReaderPluginType = Enum<ReaderManagerPluginType>::fromString(lastReaderPluginTypeString, ReaderManagerPluginType::UNKNOWN);
 
-	if (lastReaderPluginType == ReaderManagerPlugInType::UNKNOWN || !getSupportedReaderPlugInTypes().contains(lastReaderPluginType))
+	if (lastReaderPluginType == ReaderManagerPluginType::UNKNOWN || !getSupportedReaderPluginTypes().contains(lastReaderPluginType))
 	{
-		setReaderPlugInType(ReaderManagerPlugInType::NFC);
+		setReaderPluginType(ReaderManagerPluginType::NFC);
 		return;
 	}
-	setReaderPlugInType(lastReaderPluginType);
+	setReaderPluginType(lastReaderPluginType);
 #else
 	if (!mContext)
 	{
 		return;
 	}
-	mContext->setReaderPlugInTypes({ReaderManagerPlugInType::PCSC, ReaderManagerPlugInType::REMOTE_IFD, ReaderManagerPlugInType::SIMULATOR});
+	mContext->setReaderPluginTypes({ReaderManagerPluginType::PCSC, ReaderManagerPluginType::REMOTE_IFD, ReaderManagerPluginType::SIMULATOR});
 #endif
 }
 
@@ -468,16 +489,16 @@ void WorkflowModel::onApplicationStateChanged(bool pIsAppInForeground)
 	{
 		if (mRemoteScanWasRunning)
 		{
-			Env::getSingleton<ReaderManager>()->startScan(ReaderManagerPlugInType::REMOTE_IFD);
+			Env::getSingleton<ReaderManager>()->startScan(ReaderManagerPluginType::REMOTE_IFD);
 			mRemoteScanWasRunning = false;
 		}
 	}
 	else
 	{
-		mRemoteScanWasRunning = Env::getSingleton<ReaderManager>()->getPlugInInfo(ReaderManagerPlugInType::REMOTE_IFD).isScanRunning();
+		mRemoteScanWasRunning = Env::getSingleton<ReaderManager>()->getPluginInfo(ReaderManagerPluginType::REMOTE_IFD).isScanRunning();
 		if (mRemoteScanWasRunning)
 		{
-			Env::getSingleton<ReaderManager>()->stopScan(ReaderManagerPlugInType::REMOTE_IFD);
+			Env::getSingleton<ReaderManager>()->stopScan(ReaderManagerPluginType::REMOTE_IFD);
 		}
 	}
 #else
@@ -486,6 +507,24 @@ void WorkflowModel::onApplicationStateChanged(bool pIsAppInForeground)
 }
 
 
+void WorkflowModel::onPaceResultUpdated()
+{
+	if (mContext->getLastPaceResult() == CardReturnCode::OK_PUK)
+	{
+		Q_EMIT fireOnPinUnlocked();
+		return;
+	}
+	if (mContext->getLastPaceResult() == CardReturnCode::OK_CAN)
+	{
+		Q_EMIT fireOnCanSuccess();
+		return;
+	}
+
+	Q_EMIT fireOnPasswordUsed();
+
+}
+
+
 QString WorkflowModel::eidTypeMismatchError() const
 {
 	if (mContext && mContext->eidTypeMismatch())
