@@ -40,7 +40,7 @@ class StartPaosResponse
 
 	private:
 		void parse();
-		bool handleFoundElement(const QString& pElementName, const QString& pValue, const QXmlStreamAttributes& pAttributes) override;
+		bool handleFoundElement(QStringView pElementName, const QString& pValue, const QXmlStreamAttributes& pAttributes) override;
 
 		int valuetoInt(const QString& pValue) const;
 };
