@@ -5,7 +5,9 @@
 #include "StateUnfortunateCardPosition.h"
 
 #include "AbstractState.h"
+#include "Env.h"
 #include "GenericContextContainer.h"
+#include "ReaderManager.h"
 
 using namespace governikus;
 
@@ -26,8 +28,14 @@ void StateUnfortunateCardPosition::run()
 
 void StateUnfortunateCardPosition::onEntry(QEvent* pEvent)
 {
-	//: INFO The NFC signal is weak or unstable. The scan is stopped with this information in the iOS dialog.
-	stopNfcScanIfNecessary(tr("Weak NFC signal. Please\n- change the card position\n- remove the mobile phone case (if present)\n- connect the smartphone with a charging cable"));
+#if defined(Q_OS_IOS)
+	if (getContext()->getReaderPluginTypes().contains(ReaderManagerPluginType::NFC))
+	{
+		//: INFO The NFC signal is weak or unstable. The scan is stopped with this information in the iOS dialog.
+		const auto& errorMessage = tr("Weak NFC signal. Please\n- change the card position\n- remove the mobile phone case (if present)\n- connect the smartphone with a charging cable");
+		Env::getSingleton<ReaderManager>()->stopScan(ReaderManagerPluginType::NFC, errorMessage);
+	}
+#endif
 
 	AbstractState::onEntry(pEvent);
 }
