@@ -253,16 +253,18 @@ QString SelfAuthenticationData::SelfData::formatDate(const QString& pDate)
 				qMakePair(QStringLiteral("yyyy-MM-dd+hh:mm"), QLatin1String(QT_TR_NOOP("dd.MM.yyyy"))),
 	            //: LABEL ALL_PLATFORMS Date format according to https://doc.qt.io/qt/qdate.html#toString with unknown day
 				qMakePair(QStringLiteral("yyyy-MM"), QLatin1String(QT_TR_NOOP("xx.MM.yyyy"))),
+	            //: LABEL ALL_PLATFORMS Additional date format with unknown day
+				qMakePair(QStringLiteral("yyyyMM"), QLatin1String(QT_TR_NOOP("xx.MM.yyyy"))),
 	            //: LABEL ALL_PLATFORMS Date format according to https://doc.qt.io/qt/qdate.html#toString with unknown day and month
 				qMakePair(QStringLiteral("yyyy"), QLatin1String(QT_TR_NOOP("xx.xx.yyyy"))),
 			});
 
-	for (const auto& entry : formattingPattern)
+	for (const auto& [key, value] : formattingPattern)
 	{
-		const QDateTime dateTime = QDateTime::fromString(pDate, entry.first);
+		const QDateTime dateTime = QDateTime::fromString(pDate, key);
 		if (dateTime.isValid())
 		{
-			return LanguageLoader::getInstance().getUsedLocale().toString(dateTime, tr(entry.second.data()));
+			return LanguageLoader::getInstance().getUsedLocale().toString(dateTime, tr(value.data()));
 		}
 	}
 
