@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2015-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2015-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -14,6 +14,7 @@
 #include <openssl/objects.h>
 #include <openssl/x509v3.h>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -27,7 +28,7 @@ class test_Asn1StringUtil
 		{
 			ASN1_UTF8STRING* asn1String = ASN1_UTF8STRING_new();
 
-			Asn1StringUtil::setValue(QString("abc"), asn1String);
+			Asn1StringUtil::setValue("abc"_L1, asn1String);
 			QCOMPARE(asn1String->length, 3);
 			QCOMPARE(asn1String->data[0], static_cast<uchar>('a'));
 			QCOMPARE(asn1String->data[1], static_cast<uchar>('b'));
@@ -45,7 +46,7 @@ class test_Asn1StringUtil
 
 		void getValue()
 		{
-			QString utf8Text("Dieß öst äin UTF8-Đext ɃϢݢૂૂૂ");
+			const QString utf8Text(u"Dieß öst äin UTF8-Đext ɃϢݢૂૂૂ"_s);
 			ASN1_UTF8STRING* asn1String = ASN1_UTF8STRING_new();
 			ASN1_STRING_set(asn1String, utf8Text.toUtf8().data(), static_cast<int>(utf8Text.toUtf8().length()));
 
