@@ -5,10 +5,13 @@
 
 #include "SettingsModel.h"
 
+#include "AppSettings.h"
+
 #include <QSignalSpy>
 #include <QtTest>
 
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -20,7 +23,7 @@ class test_SettingsModel
 	private Q_SLOTS:
 		void testAnimations()
 		{
-			const auto model = Env::getSingleton<SettingsModel>();
+			const auto* model = Env::getSingleton<SettingsModel>();
 			QSignalSpy animationsSpy(model, &SettingsModel::fireUseAnimationsChanged);
 
 			QCOMPARE(animationsSpy.count(), 0);
@@ -44,6 +47,22 @@ class test_SettingsModel
 		}
 
 
+		void testModeOption()
+		{
+			const auto& settings = Env::getSingleton<AppSettings>()->getGeneralSettings();
+			auto* model = Env::getSingleton<SettingsModel>();
+			QCOMPARE(model->getDarkMode(), SettingsModel::ModeOption::OFF);
+
+			model->setDarkMode(SettingsModel::ModeOption::AUTO);
+			QCOMPARE(settings.getDarkMode(), "AUTO"_L1);
+			QCOMPARE(model->getDarkMode(), SettingsModel::ModeOption::AUTO);
+
+			model->setDarkMode(SettingsModel::ModeOption::ON);
+			QCOMPARE(settings.getDarkMode(), "ON"_L1);
+			QCOMPARE(model->getDarkMode(), SettingsModel::ModeOption::ON);
+		}
+
+
 };
 
 QTEST_GUILESS_MAIN(test_SettingsModel)
