@@ -156,7 +156,7 @@ class test_StatePreparePersonalization
 
 		void test_OnNetworkReplyWrongHttpStatus()
 		{
-			auto reply = new MockNetworkReply();
+			auto* reply = new MockNetworkReply();
 			mState->mReply.reset(reply, &QObject::deleteLater);
 			reply->setAttribute(QNetworkRequest::Attribute::HttpStatusCodeAttribute, 500);
 			reply->setError(QNetworkReply::NetworkError::InternalServerError, QString());
